﻿using ShoeStore.Entities;
using ShoeStore.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ShoeStore.Forms;

public partial class FormStore : Form
{
    private readonly IStoreRepository _storeRepository;
    private int? _storeId;
    public int Id
    {
        set
        {
            try
            {
                var store = _storeRepository.ReadStoreById(value);
                if (store == null)
                {
                    throw new InvalidDataException(nameof(store));
                }

                textBoxStoreType.Text = store.StoreType;
                textBoxStoreName.Text = store.StoreName;
                numericUpDownEmployees.Value = store.Employees;
                numericUpDownVisitors.Value = (decimal)store.Visitors;
                _storeId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }
    public FormStore(IStoreRepository storeRepository)
    {
        InitializeComponent();
        _storeRepository = storeRepository ??
        throw new ArgumentNullException(nameof(storeRepository));
    }
    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(textBoxStoreType.Text)
            ||
            string.IsNullOrWhiteSpace(textBoxStoreName.Text))
            {
                throw new Exception("Имеются незаполненные поля");
            }
            if (_storeId.HasValue)
            {
                _storeRepository.UpdateStore(CreateStore(_storeId.Value));
            }
            else
            {
                _storeRepository.CreateStore(CreateStore(0));
            }
            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении",
            MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }
    private void ButtonCancel_Click(object sender, EventArgs e) => Close();
    private Store CreateStore(int id) => Store.CreateEntity(id,
    textBoxStoreType.Text,
    textBoxStoreName.Text,
    Convert.ToInt32(numericUpDownEmployees.Value),
    Convert.ToDouble(numericUpDownVisitors.Value));

    private void FormStore_Load(object sender, EventArgs e)
    {

    }
}
